/*******************************************************************************
 * Copyright (c) 2009 THALES GLOBAL SERVICES.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.business.internal.helper.display;

import org.eclipse.sirius.business.api.componentization.DiagramMappingsManager;
import org.eclipse.sirius.business.api.helper.display.DisplayService;
import org.eclipse.sirius.business.api.session.Session;
import org.eclipse.sirius.viewpoint.DDiagram;
import org.eclipse.sirius.viewpoint.DDiagramElement;

/**
 * An implementation of {@link DisplayService} which return always true.
 * 
 * @author mchauvin
 */
public final class DisplayAllDisplayServiceImpl implements DisplayService {

    /**
     * Avoid instantiation.
     */
    private DisplayAllDisplayServiceImpl() {

    }

    /**
     * Initialize a new {@link DisplayService}.
     * 
     * @return a new created instance
     */
    public static DisplayService init() {
        return new DisplayAllDisplayServiceImpl();
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.sirius.business.api.helper.display.DisplayService#activateCache()
     */
    public void activateCache() {
        /* do nothing */
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.sirius.business.api.helper.display.DisplayService#deactivateCache()
     */
    public void deactivateCache() {
        /* do nothing */
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.sirius.business.api.helper.display.DisplayService#isDisplayed(org.eclipse.sirius.viewpoint.DDiagram,
     *      org.eclipse.sirius.viewpoint.DDiagramElement)
     */
    public boolean isDisplayed(final DDiagram diagram, final DDiagramElement element) {
        return true;
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.sirius.business.api.helper.display.DisplayService#computeVisibility(org.eclipse.sirius.viewpoint.DDiagram,
     *      org.eclipse.sirius.viewpoint.DDiagramElement)
     */
    public boolean computeVisibility(DiagramMappingsManager session, final DDiagram diagram, final DDiagramElement element) {
        return true;
    }

    /**
     * {@inheritDoc}
     * 
     * @see org.eclipse.sirius.business.api.helper.display.DisplayService#computeLabelVisibility(org.eclipse.sirius.viewpoint.DDiagram,
     *      org.eclipse.sirius.viewpoint.DDiagramElement)
     */
    public boolean computeLabelVisibility(DDiagram diagram, DDiagramElement element) {
        return true;
    }

    /**
     * {@inheritDoc}
     */
    public void refreshAllElementsVisibility(final DDiagram diagram) {
        // do nothing
    }

    /**
     * {@inheritDoc}
     */
    @Deprecated
    public boolean computeVisibility(Session session, DDiagram diagram, DDiagramElement element) {
        return true;
    }

}
